Module encode

Module encode 

Encoding BLP format into stream of bytes.

Modules

error

Structs

BlpWithMipmaps
BLP file bytes with vector of external mipmaps encoded

Functions

encode_blp
Encode BLP1 or BLP2 into bytes
encode_blp0
Encode BLP0 with external mipmaps
save_blp
Save given BLP image to given path. For BLP0 it will create mipmaps in the save directory with names like <root_name>.b<num bitmap>