preloaded_mipmaps

Function preloaded_mipmaps 

pub fn preloaded_mipmaps(
    mipmaps: &[Vec<u8>],
    i: usize,
) -> Result<Option<&[u8]>, Box<dyn Error>>
Helper for parse_blp when external mipmaps are located in filesystem near the root file and loaded in memory when reading the main file.