pub struct Raw3Image {
pub pixels: Vec<u32>,
}Expand description
Each mipmap contains what appears to be
32 bit BGRA data. alpha_bits seems to represent a set of bit flags
rather than depth, as all images of this type seem to have 4 bytes per
pixel regardless of depth, and it has been seen to exceed 8. Their
meaning is unknown.
Fields
pixels: Vec<u32>Implementations